@@ -23,10 +23,11 @@ from .calibration import calibration as cb
 from .calibration import Calibration, CalibrationSource
 from .graph import GraphMember
 from .gui import GRS
-from .modification import GenericMod, Modification
+from .modification import Modification
 from .picklable import Attributes
 from .region import record as rc
 from .region import Region, View, Record
+from pyoti.plugins.modifications.generic import GenericMod
 
 
 def if_open(func):
@@ -221,7 +222,7 @@ class Experiment(object):
         self._graphroot._v_absdir = absdir
 
         # Update the database of an experiment file created with an old version
-        update._update_db(self)
+        update.update_db(self)
 
         # Save the current timestamp
         # now = datetime.datetime.now()
@@ -472,7 +473,7 @@ class Experiment(object):
         Add a group which will retrieve its data from a given `parent`.
         The type of the group is determined by the parameter `group_type`.
         The different types of groups are defined in the configfile (`cfgfile`,
-        defaults to "etc/group.cfg").
+        defaults to "groups.cfg").
 
         A group can be either (a) created for solely selecting a timespan of
         the data retrieved by the parent or (b) additionally modifying the
@@ -505,7 +506,7 @@ class Experiment(object):
             The configfile where the different types of groups are defined.
             Values can be overwritten by parameters `traces`, `description`,
             and `modclass`
-            Defaults to "etc/group.cfg"
+            Defaults to "groups.cfg"
         traces : str, int, list of str/int, or slice
             Select the traces the user is shown to adjust the timespan from.
             The selection of the traces does *not* influence the traces
@@ -530,17 +531,16 @@ class Experiment(object):
             Depending on the type of group, return either the added `View` or
             the `Modification`.
         """
-        if cfgfile is None:
-            directory = os.path.dirname(globals()['__file__'])
-            cfgfile = os.path.join(directory, 'etc', 'group.cfg')
+        cfgfile = cfgfile or 'groups.cfg'
         cfg = cf.read_cfg_file(cfgfile)
+
         description = description or cf.get_cfg_option(cfg, sec=group_type,
                                                        opt='description')
         traces = (traces or cf.get_cfg_list(cfg, sec=group_type, opt='traces')
                   or None)
         modclass = modclass or cf.get_cfg_class(cfg, sec=group_type,
-                                                std_mod='.modification',
-                                                cls_opt='modclass')
+                                    std_mod='.plugins.modifications.generic',
+                                    cls_opt='modclass')
 
         if not modclass:
             return self.add_view(name, parent_region, group=group,
@@ -666,6 +666,48 @@ class Experiment(object):
 
         return view
 
+    @if_open
+    def show_view(self, view, group=None, traces=None, description=None,
+                  xlim=None):
+        """
+        Graphically inspect a View.
+
+        Parameters
+        ----------
+        view : str or GraphMember
+            Name of the View, a GraphMember with the name, or the View itself.
+        group : str, optional
+            The name of the group. Defaults to None or `view.group`.
+        traces : str, int, list of str/int, or slice
+            Select the traces the user is shown to adjust the timespan from.
+            The selection of the traces does *not* influence the traces
+            contained in the View. Defaults to all traces available in the
+            View determined by `view`.
+        description : str
+            Short description of what the selection of the timespan is used
+            for.
+        xlim : (float, float), optional
+            The timespan (s) plotted.
+            Defaults to (View.tmin, View.tmax) of the View determined by
+            `view`.
+        """
+        view = self.view(name=view, group=group)
+        if view is not None:
+            # if traces is None or (isinstance(traces, list)
+            # and len(traces) == 0):
+            traces = view.traces_available(traces)
+            # tc.normalize(traces)
+            # traces = traces or view.traces
+            if description is None:
+                description = view.name
+            self._grs.init_ifig(view.timevector,
+                                view.get_data(traces=traces, copy=False),
+                                view.samplingrate,
+                                traces,
+                                xlim=xlim,
+                                description=description,
+                                select=False)
+
     @if_open
     def adjust_view(self, view, group=None, traces=None, description=None,
                     xlim=None, set_last_adjusted_view=True):
@@ -992,7 +1034,7 @@ class Experiment(object):
     @if_open
     def append_to(self, name, append_region, group=None, append_group=None,
                   after=None, after_group=None, before=None,
-                  before_group=None):
+                  before_group=None, update_indices=True):
         """
         Appends a Region as a parent to a View.
 
@@ -1022,6 +1064,8 @@ class Experiment(object):
         before_group : str, optional
             Name of the group of the before region. Defaults to None or
             `before_region.group`.
+        update_indices : bool, optional
+            Update the indices of the child Regions. Defaults to True.
 
         Returns
         -------
@@ -1029,14 +1073,19 @@ class Experiment(object):
             True if the region was appended or is already a parent. Otherwise
             return False.
         """
-        group = group or name
+        if group is None:
+            if isinstance(name, GraphMember):
+                group = name.group
+            else:
+                group = name
         view = self.view(name=name, group=group)
         append_region = self.region(name=append_region, group=append_group)
         if view is not None and append_region is not None:
             after = self.region(name=after, group=after_group)
             before = self.region(name=before, group=before_group)
             return view.parent.add_parent(append_region, after=after,
-                                          before=before)
+                                          before=before,
+                                          update_indices=update_indices)
         return False
 
     @if_open
@@ -1191,7 +1240,8 @@ class Experiment(object):
             or self.remove_record(record=name, group=group)
 
     @if_open
-    def remove_from(self, view, remove_region, group=None, remove_group=None):
+    def remove_from(self, view, remove_region, group=None, remove_group=None,
+                    update_indices=True):
         """
         Remove a parent Region of a (concatenated) view. If the region is the
         last in the view, the view and all its descendants are removed, too.
@@ -1212,6 +1262,8 @@ class Experiment(object):
         remove_group : str, optional
             Name of the group of the remove region. Defaults to None or
             `remove_region.group`.
+        update_indices : bool, optional
+            Update the indices of the child Regions. Defaults to True.
 
         Returns
         -------
@@ -1222,13 +1274,14 @@ class Experiment(object):
         remove_region = self.region(name=remove_region, group=remove_group)
 
         if view is not None and remove_region is not None:
-            view.parent.remove_parent(remove_region)
+            view.parent.remove_parent(remove_region,
+                                      update_indices=update_indices)
 
         return remove_region
 
     @if_open
     def replace_in(self, view, remove_region, with_region, group=None,
-                   remove_group=None, with_group=None):
+                   remove_group=None, with_group=None, update_indices=True):
         """
         Replace a parent Region of a view with another one.
 
@@ -1251,6 +1304,8 @@ class Experiment(object):
         with_group : str, optional
             Name of the group of the with region. Defaults to None or
             `with_region.group`.
+        update_indices : bool, optional
+            Update the indices of the child Regions. Defaults to True.
 
         Returns
         -------
@@ -1264,8 +1319,10 @@ class Experiment(object):
                 and remove_region is not None
                 and with_region is not None
                 and remove_region is not with_region):
-            self.append_to(view, with_region, after=remove_region)
-            self.remove_from(view, remove_region)
+            self.append_to(view, with_region, after=remove_region,
+                           update_indices=update_indices)
+            self.remove_from(view, remove_region,
+                             update_indices=update_indices)
 
         return remove_region
 
@@ -1416,6 +1473,8 @@ class Experiment(object):
         -----
         The returned Region can be either a Record or a View.
         """
+        if name is None and group is None:
+            return None
         return self.member(name=name, group=group, instance_class=Region)
 
     @if_open
@@ -1433,6 +1492,8 @@ class Experiment(object):
         -------
         Record or None
         """
+        if name is None and group is None:
+            return None
         return self.member(name=name, group=group, instance_class=Record,
                            level=1)
 
@@ -1451,6 +1512,8 @@ class Experiment(object):
         -------
         View or None
         """
+        if name is None and group is None:
+            return None
         return self.member(name=name, group=group, instance_class=View)
 
     @if_open
@@ -1469,6 +1532,8 @@ class Experiment(object):
         -------
         Modification or None
         """
+        if name is None and group is None:
+            return None
         return self.member(name=name, group=group, instance_class=Modification)
 
     @if_open
@@ -1922,12 +1987,15 @@ class Experiment(object):
                             self.__class__.__name__, '>'])
 
 
-def create_experiment(**kwargs):
+def create_experiment(return_last_created=True, **kwargs):
     """
     Create a new Experiment or get the last created one.
 
     Parameters
     ----------
+    return_last_created : bool
+        If an experiment was already created in the python kernel instance,
+        return that experiment instead of creating a new one.
     **kwargs
         Parameters for the initialization of an instance of Experiment().
 
@@ -1936,10 +2004,14 @@ def create_experiment(**kwargs):
     Experiment
         The new or the last created Experiment.
     """
-    return Experiment.created_last or Experiment(**kwargs)
+    if return_last_created:
+        return Experiment.created_last or Experiment(**kwargs)
+    else:
+        return Experiment(**kwargs)
 
 
-def open_experiment(filename=None, directory=None, **kwargs):
+def open_experiment(filename=None, directory=None, return_last_created=True,
+                    **kwargs):
     """
     Create a new Experiment or get the last created one.
     Optionally, open an experiment file `filename'.
@@ -1952,6 +2024,9 @@ def open_experiment(filename=None, directory=None, **kwargs):
         If `filename` alone is not sufficient to describe the location of the
         experiment file, you can provide a `directory`, where the path of
         `filename` is located in.
+    return_last_created : bool
+        If an experiment was already created in the python kernel instance,
+        return that experiment instead of creating a new one.
     **kwargs
         Parameters for the initialization of an instance of Experiment().
 
@@ -1960,7 +2035,8 @@ def open_experiment(filename=None, directory=None, **kwargs):
     Experiment
         The Experiment with the opened file.
     """
-    experiment = create_experiment(**kwargs)
+    experiment = create_experiment(return_last_created=return_last_created,
+                                   **kwargs)
     experiment.open(filename=filename, directory=directory)
     return experiment
 
